Learn R Programming

Rtauchen (version 1.0)

Rtauchen: Rtauchen

Description

This function generates a matrix of transition probabilites of a finite-state Markov chain that mimics an AR(1) process with persistence parameter llamda, standard deviation ssigma and a fixed parameter m.

Usage

Rtauchen(ne, ssigma_eps, llambda_eps, m)

Arguments

ne
Number of points of the grid of the finite-state Markov chain that mimics the AR(1) process
ssigma_eps
Standard deviation of exogenous shock in the AR(1) process
llambda_eps
Persistence parameter of the AR(1) process
m
Tauchen parameter for the width of the process (number of standard deviations of the AR(1) process covered by the grid)

Value

A matrix with the corresponding to the transition matrix of the finite-state Markov chain that approximates the AR(1) process

Details

See Tauchen (1986) for details.

Examples

Run this code
results = Rtauchen(2, 1.0e-5, 0.1,0.4)
results

Run the code above in your browser using DataLab